@@ -40,6 +40,11 @@ ggemmeans <- function(model,
     terms <- all.vars(terms)
   }
 
+  # "terms" can also be a list, convert now
+  if (!missing(terms) && !is.null(terms)) {
+    terms <- .list_to_character_terms(terms)
+  }
+
   # tidymodels?
   if (inherits(model, "model_fit")) {
     model <- model$fit
