@@ -67,7 +67,7 @@ residualize_over_grid.data.frame <- function(grid, model, pred_name, ...) {
   old_d <- old_d[, colnames(grid)[colnames(grid) %in% colnames(old_d)], drop = FALSE]
 
   if (!.is_grid(grid)) {
-    stop("Grid for partial residuals must be a fully crossed grid.")
+    insight::format_error("Grid for partial residuals must be a fully crossed grid.")
   }
 
   # for each var
@@ -95,7 +95,7 @@ residualize_over_grid.data.frame <- function(grid, model, pred_name, ...) {
   )
 
   if (is.null(res)) {
-    warning("Could not extract residuals.", call. = FALSE)
+    insight::format_warning("Could not extract residuals.")
     return(NULL)
   }
 
@@ -110,7 +110,7 @@ residualize_over_grid.data.frame <- function(grid, model, pred_name, ...) {
 #' @rdname residualize_over_grid
 #' @export
 residualize_over_grid.ggeffects <- function(grid, model, protect_names = TRUE, ...) {
-  new_d <- as.data.frame(grid)
+  new_d <- as.data.frame(grid, terms_to_colnames = FALSE)
   new_d <- new_d[colnames(new_d) %in% c("x", "group", "facet", "panel", "predicted")]
 
   colnames(new_d)[colnames(new_d) %in% c("x", "group", "facet", "panel")] <- attr(grid, "terms")
