@@ -1,11 +1,10 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("quantreg")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("quantreg") &&
+  getRversion() >= "3.6.0"
 )) {
 
-  context("ggeffects, quantreg")
-
   data(stackloss)
   m1 <- rq(stack.loss ~ Air.Flow + Water.Temp, data = stackloss, tau = .25)
 
@@ -15,10 +14,10 @@ if (suppressWarnings(
   })
 
   test_that("ggeffect, rq", {
-    expect_error(ggeffect(m1, "Air.Flow"))
+    expect_null(ggeffect(m1, "Air.Flow"))
   })
 
   test_that("ggemmeans, rq", {
-    expect_error(ggemmeans(m1, "Air.Flow"))
+    expect_null(ggemmeans(m1, "Air.Flow"))
   })
 }
